/* $Id: display.c,v 1.9 2004/03/16 21:56:02 ian Exp $
 * Copyright (c) 2003 Ian Glover
 *
 * This file is part of wmfuzzy and is distributed under the GNU
 * GPL. See file COPYING for details.
 */
#include "display.h"
#include "xdisplay.h"
#include <stdlib.h>
#include <string.h>

static /*@null@*/ Callback update_fn;
static /*@null@*/ Callback expose_fn;
static /*@null@*/ Callback clicked_fn;

void call_update_fn(void);
void call_expose_fn(void);
void call_clicked_fn(void);
static void lib_initialise(void);

void lib_initialise(void)
{
  update_fn = NULL;
  expose_fn = NULL;
  clicked_fn = NULL;
}

void call_update_fn(void)
{
  if (NULL != update_fn)
  {
    (*update_fn)();
  }
}

void call_expose_fn(void)
{
  if (NULL != expose_fn)
  {
    (*expose_fn)();
  }
}

void call_clicked_fn(void)
{
  if (NULL != clicked_fn)
  {
    (*clicked_fn)();
  }
}    

int main(int argc, char* argv[])
{
  lib_initialise();
  x_initialise(argc, argv);

  set_app_name(argv[0]);
  app_setup(argc, argv);    
  
  x_main_loop();
  x_free_resources();
  
  return 0;
}

/* Publically visible functions. */
void set_message(char* lines[], int nLines)
{
  int i;
  
  if (nLines > MAX_LINES) { nLines = MAX_LINES; }

  for (i = 0; i < nLines; ++i)
  {
    if (0 != x_msg_lines[i])
    {
      free(x_msg_lines[i]);
    }
    x_msg_lines[i] = malloc(strlen(lines[i]) + 1);
    memset(x_msg_lines[i], 0, strlen(lines[i] + 1));
    strcpy(x_msg_lines[i], lines[i]);
  }
  for ( ; i < MAX_LINES; ++i)
  {
    x_msg_lines[i] = 0;
  }
}

void set_app_name(const char* name)
{
  x_set_app_name(name);
}

void set_update_delay(int seconds)
{
  x_set_update_delay(seconds);
}

void set_update_callback(Callback fn)
{
  update_fn = fn;
}

void set_expose_callback(Callback fn)
{
  expose_fn = fn;
}

void set_clicked_callback(Callback fn)
{
  clicked_fn = fn;
} 

void set_foreground(const char* colour)
{
  x_set_foreground(colour);
}

void set_background(const char* colour)
{
  x_set_background(colour);
}
